@@ -1,6 +1,6 @@
 package Log::Any::Adapter::JSON;
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use strict;
 use warnings;
@@ -176,7 +176,7 @@ __END__
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =encoding utf8
 
@@ -229,7 +229,7 @@ will be discarded. Default is trace.
 
 =head2 encoding
 
-Defaults to C<UTF-8>. Pass a different encoding to change the bindmode applied
+Defaults to C<UTF-8>. Pass a different encoding to change the binmode applied
 to the log output.
 
 =head2 localtime
@@ -357,9 +357,9 @@ Output is a B<single line> with JSON like:
 
   {
     "category":"main",
-    "hash_data":{
-      "foo":"bar"
-    },
+    "hash_data":[
+      {"foo":"bar"}
+    ],
     "level":"debug",
     "message":"the message",
     "time":"2021-03-03T17:23:25.731243Z",
